@@ -123,14 +123,12 @@ typedef signed int intptr_t;
 #           define GTA_EXPORT
 #       endif
 #   else
-#       if defined _MSVC && !defined GTA_STATIC
+#       if defined _MSC_VER && !defined GTA_STATIC
 #           define GTA_EXPORT __declspec(dllimport)
 #       else
 #           define GTA_EXPORT
 #       endif
 #   endif
-#elif defined GTA_BUILD && defined HAVE_VISIBILITY
-#   define GTA_EXPORT __attribute__((visibility("default")))
 #else
 #   define GTA_EXPORT
 #endif
